pub struct BrowserServer { /* private fields */ }Expand description
MCP Server wrapper for BrowserSession
This struct holds a browser session and provides thread-safe access for MCP tool execution.
Implementations
Sourceimpl BrowserServer
impl BrowserServer
Sourcepub fn with_options(options: LaunchOptions) -> Result<Self, String>
pub fn with_options(options: LaunchOptions) -> Result<Self, String>
Create a new browser server with custom launch options
Sourceimpl BrowserServer
impl BrowserServer
Generated tool metadata function for browser_navigate
Sourcepub fn browser_click_tool_attr() -> Tool
pub fn browser_click_tool_attr() -> Tool
Generated tool metadata function for browser_click
Sourcepub fn browser_form_input_fill_tool_attr() -> Tool
pub fn browser_form_input_fill_tool_attr() -> Tool
Generated tool metadata function for browser_form_input_fill
Sourcepub fn browser_get_text_tool_attr() -> Tool
pub fn browser_get_text_tool_attr() -> Tool
Generated tool metadata function for browser_get_text
Sourcepub fn browser_screenshot_tool_attr() -> Tool
pub fn browser_screenshot_tool_attr() -> Tool
Generated tool metadata function for browser_screenshot
Sourcepub fn browser_evaluate_tool_attr() -> Tool
pub fn browser_evaluate_tool_attr() -> Tool
Generated tool metadata function for browser_evaluate
Sourcepub fn browser_wait_tool_attr() -> Tool
pub fn browser_wait_tool_attr() -> Tool
Generated tool metadata function for browser_wait
Sourcepub fn browser_get_markdown_tool_attr() -> Tool
pub fn browser_get_markdown_tool_attr() -> Tool
Generated tool metadata function for browser_get_markdown
Sourcepub fn browser_read_links_tool_attr() -> Tool
pub fn browser_read_links_tool_attr() -> Tool
Generated tool metadata function for browser_read_links
Sourcepub fn browser_get_clickable_elements_tool_attr() -> Tool
pub fn browser_get_clickable_elements_tool_attr() -> Tool
Generated tool metadata function for browser_get_clickable_elements