Module tools

Module tools 

Browser automation tools module

This module provides a framework for browser automation tools and includes implementations of common browser operations.

Re-exports

pub use click::ClickParams;
pub use close::CloseParams;
pub use close_tab::CloseTabParams;
pub use evaluate::EvaluateParams;
pub use extract::ExtractParams;
pub use go_back::GoBackParams;
pub use go_forward::GoForwardParams;
pub use hover::HoverParams;
pub use input::InputParams;
pub use markdown::GetMarkdownParams;
pub use navigate::NavigateParams;
pub use new_tab::NewTabParams;
pub use press_key::PressKeyParams;
pub use read_links::ReadLinksParams;
pub use screenshot::ScreenshotParams;
pub use scroll::ScrollParams;
pub use select::SelectParams;
pub use snapshot::SnapshotParams;
pub use switch_tab::SwitchTabParams;
pub use tab_list::TabListParams;
pub use wait::WaitParams;

Modules

click
close
close_tab
evaluate
extract
go_back
go_forward
hover
html_to_markdown
input
markdown
navigate
new_tab
press_key
read_links
readability_script
screenshot
scroll
select
snapshot
switch_tab
tab_list
wait

Structs

ToolContext
Tool execution context
ToolRegistry
Tool registry for managing and accessing tools
ToolResult
Result of tool execution

Traits

DynTool
Type-erased tool trait for dynamic dispatch
Tool
Trait for browser automation tools with associated parameter types