pub struct ReadLinksParams {}Trait Implementations
Sourceimpl Clone for ReadLinksParams
impl Clone for ReadLinksParams
Sourcefn clone(&self) -> ReadLinksParams
fn clone(&self) -> ReadLinksParams
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReadLinksParams
impl Debug for ReadLinksParams
Sourceimpl<'de> Deserialize<'de> for ReadLinksParams
impl<'de> Deserialize<'de> for ReadLinksParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ReadLinksParams
impl JsonSchema for ReadLinksParams
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ReadLinksParams
impl RefUnwindSafe for ReadLinksParams
impl Send for ReadLinksParams
impl Sync for ReadLinksParams
impl Unpin for ReadLinksParams
impl UnwindSafe for ReadLinksParams