Module tools

Module tools 

Browser automation tools module

This module provides a framework for browser automation tools and includes implementations of common browser operations.

Re-exports

pub use click::ClickParams;
pub use evaluate::EvaluateParams;
pub use extract::ExtractParams;
pub use get_clickable_elements::GetClickableElementsParams;
pub use input::InputParams;
pub use markdown::GetMarkdownParams;
pub use navigate::NavigateParams;
pub use read_links::ReadLinksParams;
pub use screenshot::ScreenshotParams;
pub use wait::WaitParams;

Modules

click
evaluate
extract
get_clickable_elements
input
markdown
navigate
read_links
screenshot
wait

Structs

ToolContext
Tool execution context
ToolRegistry
Tool registry for managing and accessing tools
ToolResult
Result of tool execution

Traits

DynTool
Type-erased tool trait for dynamic dispatch
Tool
Trait for browser automation tools with associated parameter types